==> dde-network-core_1.0.47.orig.tar.xz: dde-network-core-1.0.47/dde-network-dialog/translations/dde-network-dialog_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
<context>
    <name>DeviceControllItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>Réseau sans fil</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Réseau filaire</translation>
    </message>
</context>
<context>
    <name>WirelessItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>Se connecter à un réseau caché</translation>
    </message>
    <message>
        <source>Wrong password</source>
        <translation>Mauvais mot de passe</translation>
    </message>
    <message>
        <source>Password required to connect %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password</source>
        <translation>Mot de passe</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Connect</source>
        <comment>button</comment>
        <translation>Relier</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Point d&apos;accès</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protocole</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Type de sécurité</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Bande</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Canal</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Interface</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>passerelle</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>DNS primaire</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Masque de réseau</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Préfixe</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Vitesse</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Périphérique désactivé </translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Connecté mais pas d’accès internet</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Pas connecté</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Câble réseau débranché</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Connexion en cours</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Authentification</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Obtention d&apos;adresse IP</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Connecté</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Déconnecté</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Échoué</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Réseau filaire</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Réseau filaire %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Réseau sans fil</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Réseau sans fil %1</translation>
    </message>
</context>
</TS>

==> dde-network-core_1.0.69.orig.tar.xz: dde-network-core-1.0.69/dde-network-dialog/translations/dde-network-dialog_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
<context>
    <name>DeviceControllItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>Réseau sans fil</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Réseau filaire</translation>
    </message>
</context>
<context>
    <name>WirelessItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>Se connecter à un réseau caché</translation>
    </message>
    <message>
        <source>Wrong password</source>
        <translation>Mauvais mot de passe</translation>
    </message>
    <message>
        <source>Password required to connect %1</source>
        <translation>Mot de passe requis pour se connecter %1</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Mot de passe</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Connect</source>
        <comment>button</comment>
        <translation>Relier</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>Nom (SSID)</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Point d&apos;accès</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protocole</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Type de sécurité</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Bande</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Canal</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Interface</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>passerelle</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>DNS primaire</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Masque de réseau</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Préfixe</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Vitesse</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Périphérique désactivé </translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Connecté mais pas d’accès internet</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Pas connecté</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Câble réseau débranché</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Connexion en cours</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Authentification</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Obtention d&apos;adresse IP</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Connecté</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Déconnecté</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Échoué</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Obtenir l&apos;adresse</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Réseau filaire</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Réseau filaire %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Réseau sans fil</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Réseau sans fil %1</translation>
    </message>
</context>
</TS>
